# Extra thick

Common methods that I use all the time but don't necessarily feel they should
be part of the standard library

To test:

    cd tests
    python3 -m virtualenv venv
    . venv/bin/activate
    pip3 install -r requirements.txt
    ./integration.py

Exit code of 0 means success
